@@ -8,10 +8,8 @@ from enum import Enum
 from signalrcore.hub_connection_builder import HubConnectionBuilder
 
 SERVER_BROKER_URL: str = "http://broker.tr7.pl"
-FORMAT: str = "%(asctime)s | [%(levelname)s] | %(message)s"
 
-logging.basicConfig(level=logging.DEBUG, format=FORMAT)
-log = logging.getLogger(__name__)
+_LOGGER = logging.getLogger(__name__)
 
 
 # Frame declaration
@@ -34,7 +32,6 @@ class Method(Enum):
 
 
 class Status(Enum):
-
     OK = 0
     UnknownError = 1
     FatalError = 2
@@ -51,9 +48,17 @@ class Status(Enum):
     UserNotLoggedIn = 13
 
 
+class ConnectionError(Exception):
+    """Raised when connection error."""
+
+    def __init__(self, message: str = "Connection error!") -> None:
+        """Init"""
+        super().__init__(message)
+        self.message = message
+
+
 class Controller:
     def __init__(self, controller_serial, controller_pin, login, password):
-
         self.controller_serial: str = controller_serial
 
         self.controller_pin: int = controller_pin
@@ -69,7 +74,6 @@ class Controller:
         self.password: str = password
 
     def start(self) -> None:
-
         """Authorize user"""
 
         self.hub_connection.send(
@@ -77,12 +81,10 @@ class Controller:
         )
 
     def auth_result(self, auth_result) -> None:
-
         """Check if user has been authorized"""
 
         if auth_result:
-
-            log.debug("User has been authorized")
+            _LOGGER.info("User has been authorized")
 
             frame = dumps(
                 asdict(
@@ -96,26 +98,22 @@ class Controller:
                 )
             )
 
-            log.debug("Sent frame: %s", frame)
+            _LOGGER.info("Sent frame: %s", frame)
 
             self.send_frame(frame)
 
         else:
-
-            log.debug("Authorization failed!")
+            _LOGGER.info("Authorization failed!")
 
     async def send_and_wait_for_response(
         self, dataframe: DataFrame, ms_timeout: int = 5000
     ) -> DataFrame:
-
         """Send frames and wait for response"""
 
         result = asyncio.Future()
 
         def on_response_received(frame: DataFrame):
-
             if frame.TransactionId == dataframe.TransactionId:
-
                 self._on_receive.on_change -= on_response_received
 
                 result.set_result(frame)
@@ -129,60 +127,58 @@ class Controller:
         return result.result
 
     def data_handler(self, data: list) -> None:
-
         """Handle incoming data"""
 
         frame = loads(data[1])
 
         if frame["Resource"] != "/homemessaging/notify/message/new":
-
-            log.debug("Sent by: %s data:\n %s", data[0], {dumps(frame, indent=3)})
+            _LOGGER.info("Sent by: %s data:\n %s", data[0], {dumps(frame, indent=3)})
 
     def send_frame(self, data_frame) -> None:
-
         """Send frame to controller"""
 
         self.hub_connection.send("SendTo", [self.controller_serial, data_frame])
 
-    async def establish_connection(self) -> None:
-
+    def establish_connection(self) -> None:
         """Main function used for connecting with controller and handle callbacks"""
 
-        result = await requests.get(
+        result = requests.get(
             f"{SERVER_BROKER_URL}/api/connections/broker/whichserver/{self.controller_serial}",
             timeout=5000,
         )
 
-        if result.status_code != 200:
+        _LOGGER.info("Entered")
 
+        if result.status_code != 200:
             raise requests.exceptions.ConnectionError
 
         else:
-
-            log.info("Broker address has been acquired!")
+            _LOGGER.info("Broker address has been acquired!")
 
             self.server_uri = f"https://{result.text}/broker"
 
-            log.debug(self.server_uri)
+            _LOGGER.info(self.server_uri)
 
-        self.hub_connection = (
-            HubConnectionBuilder()
-            .with_url(self.server_uri)
-            .configure_logging(logging.INFO)
-            .with_automatic_reconnect(
-                {
-                    "type": "raw",
-                    "keep_alive_interval": 10,
-                    "reconnect_interval": 5,
-                    "max_attempts": 5,
-                }
+            _LOGGER.info(self.server_uri)
+
+            self.hub_connection = (
+                HubConnectionBuilder()
+                .with_url(self.server_uri)
+                .configure_logging(logging.INFO)
+                .with_automatic_reconnect(
+                    {
+                        "type": "raw",
+                        "keep_alive_interval": 10,
+                        "reconnect_interval": 5,
+                        "max_attempts": 5,
+                    }
+                )
+                .build()
             )
-            .build()
-        )
 
-        self.hub_connection.on("SendError", log.debug)
-        self.hub_connection.on("Registration", log.debug)
+        self.hub_connection.on("SendError", _LOGGER.info)
+        self.hub_connection.on("Registration", _LOGGER.info)
         self.hub_connection.on("Authorization", self.auth_result)
         self.hub_connection.on("Data", self.data_handler)
         self.hub_connection.on_open(self.start)
-        await self.hub_connection.start()
+        self.hub_connection.start()
